@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
@@ -13,6 +13,13 @@ prhead_semaphore()
 	mprintf(SPTR"  CNT SLEEP\n", "ADDR");
 }
 
+void
+__print_semaphore(semp)
+	struct semaphore *semp;
+{
+	mprintf("%4d %5d", ATOMIC_READ(semp->count), semp->waking);
+}
+
 addr_t
 print_semaphore(addr)
 addr_t addr;
@@ -20,6 +27,8 @@ addr_t addr;
 	struct semaphore sem;
 
 	memread(addr, sizeof(struct semaphore), &sem, "semaphore");
-	mprintf(FPTR " %4d %5d\n", addr, sem.count.counter, sem.waking);
-	return 0;
+	mprintf(FPTR " ", addr);
+	__print_semaphore(&sem);
+	mprintf("\n");
+	return ATOMIC_READ(sem.count);
 }
