@@ -35,7 +35,7 @@ file()
 	if (argcnt > optind) {
 		if (!full) mprintf(head_file);
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			if (full) mprintf(head_file);
 			addr = print_file(addr, full);
 		}
