@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <sys/stat.h>
@@ -54,7 +54,7 @@ buffer_head()
 		}
 		if (!full) prhead_buffer_head();
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			if (full) prhead_buffer_head();
 			addr = print_buffer_head(addr, full, -1);
 		}
