@@ -299,6 +299,9 @@ print_superblock(addr, full)
 		mprintf("\ts_blocksize_bits: %x\n", sb.s_blocksize_bits);
 		mprintf("\tdirt: %x\n", sb.s_dirt);
 		mprintf("\tdquot_operations: " FPTR "\n", sb.dq_op);
+		mprintf("\tlock:");
+		__print_semaphore(&sb.s_lock);
+		mprintf("\n");
 		mprintf("\tu: " FPTR "\n", addr + OFFSET(struct super_block, u));
 	}
 
@@ -506,3 +509,61 @@ print_block_device(addr, eflag)
 	mprintf("\n");
 	return (addr_t)bd.bd_hash.next;
 }
+
+void
+prhead_file_lock()
+{
+	mprintf(SPTR " " SPTR "   PID " SPTR " T      START        END FLAGS\n",
+		"ADDR", "OWNER", "FILE");
+}
+
+addr_t
+print_file_lock(addr, full, chain)
+	addr_t addr;
+	int full;
+	int chain;
+{
+	struct file_lock fl;
+
+	switch (chain) {
+	case 1:
+		addr -= OFFSET(struct file_lock, fl_link);
+		break;
+	}
+	memread(addr, sizeof(fl), &fl, "file_lock");
+	mprintf(FPTR " " FPTR " %5d " FPTR " ",
+		addr, fl.fl_owner, fl.fl_pid, fl.fl_file);
+	switch (fl.fl_type) {
+	case F_UNLCK:			mprintf("-");	break;
+	case F_WRLCK:			mprintf("W");	break;
+	case F_RDLCK:			mprintf("R");	break;
+	case F_WRLCK | F_INPROGRESS:	mprintf("w");	break;
+	case F_RDLCK | F_INPROGRESS:	mprintf("r");	break;
+	default:			mprintf("?");	break;
+	}
+	mprintf(" %10llx", fl.fl_start);
+	if (fl.fl_end == OFFSET_MAX) {
+		mprintf(" offset_max");
+	} else {
+		mprintf(" %10llx", fl.fl_end);
+	}
+	mprintbit(flflags, fl.fl_flags);
+	mprintf("\n");
+
+	if (full) {
+		mprintf("  notify: " FPTR "\n", fl.fl_notify);
+		mprintf("  insert: " FPTR "\n", fl.fl_insert);
+		mprintf("  rename: " FPTR "\n", fl.fl_remove);
+		mprintf("  fasync: " FPTR "\n", fl.fl_fasync);
+#ifdef _file_lock_has_fl_break_time
+		mprintf("  break_time: %8lx\n", fl.fl_break_time);
+#endif
+	}
+
+	switch (chain) {
+	default:
+	case 0:	return (addr_t) fl.fl_next;
+	case 1:	return (addr_t) fl.fl_link.next;
+	case 2:	return (addr_t) fl.fl_block.next - OFFSET(struct file_lock, fl_block);
+	}
+}
