@@ -8,6 +8,8 @@
 #include <linux/mm.h>
 #include <linux/mmzone.h>
 
+#include "flags_mmzone.h"
+
 void
 prhead_zone()
 {
@@ -25,8 +27,15 @@ print_zone(addr, full)
 
 	memread(addr, sizeof(zone), &zone, "zone");
 	if (!full) {
-		mprintf(FPTR " %6lx " FPTR " %6lx ",
-			addr, zone.free_pages, zone.zone_mem_map, zone.size);
+		mprintf(FPTR " %6lx " FPTR " ",
+			addr, zone.free_pages, zone.zone_mem_map);
+#ifdef _zone_struct_has_size
+		mprintf("%6lx ", zone.size);
+#else
+#ifdef _zone_struct_has_memsize
+		mprintf("%6lx ", zone.memsize);
+#endif
+#endif /*_zone_struct_has_size*/
 		memread((addr_t)zone.name, sizeof(buf), &buf, "name");
 		mprint_str(buf, sizeof(buf));
 		mprintf("\n");
@@ -78,7 +87,15 @@ print_zone(addr, full)
 	memread((addr_t)zone.name, sizeof(buf), &buf, "name");
 	mprint_str(buf, sizeof(buf));
 	mprintf("\"\n");
+#ifdef _zone_struct_has_size
 	mprintf("size               %lx\n", zone.size);
+#endif
+#ifdef _zone_struct_has_totalsize
+	mprintf("totalsize          %lx\n", zone.totalsize);
+#endif
+#ifdef _zone_struct_has_memsize
+	mprintf("memsize            %lx\n", zone.memsize);
+#endif
 	return 0;
 }
 
