@@ -67,18 +67,20 @@ prhead_task(sw)
 	case 2:
 		p = "FS";	break;
 	case 3:
+		p = "FILES";	break;
+	case 4:
 		p = "USER";	break;
 #ifdef _task_struct_has_signal
-	case 4:
+	case 5:
 		p = "SIGNAL";	break;
 #else
 #ifdef _task_struct_has_sig
-	case 4:
+	case 5:
 		p = "SIG";	break;
 #endif
 #endif /*_task_struct_has_signal*/
 #ifdef _task_struct_has_namespace
-	case 5:
+	case 6:
 		p = "NAMESPAC";	break;
 #endif /*_task_struct_has_namespace*/
 	}
@@ -121,18 +123,20 @@ print_task(addr, full, sw)
 	case 2:
 		mprintf(FPTR, ts.fs);	break;
 	case 3:
+		mprintf(FPTR, ts.files);break;
+	case 4:
 		mprintf(FPTR, ts.user);	break;
 #ifdef _task_struct_has_signal
-	case 4:
+	case 5:
 		mprintf(FPTR, ts.signal);	break;
 #else
 #ifdef _task_struct_has_sig
-	case 4:
+	case 5:
 		mprintf(FPTR, ts.sig);	break;
 #endif
 #endif /*_task_struct_has_signal*/
 #ifdef _task_struct_has_namespace
-	case 5:
+	case 6:
 		mprintf(FPTR, ts.namespace);	break;
 #endif /*_task_struct_has_namespace*/
 	}
@@ -248,6 +252,12 @@ print_mm_struct(addr, vflag)
 	mprintf("mm_users:   %x\n", ATOMIC_READ(mm.mm_count));
 	mprintf("map_count:  %x\n", mm.map_count);
 	mprintf("mmlist:     " FPTR " " FPTR "\n", mm.mmlist.next, mm.mmlist.prev);
+	mprintf("code:       %8lx %8lx\n", mm.start_code, mm.end_code);
+	mprintf("data:       %8lx %8lx\n", mm.start_data, mm.end_data);
+	mprintf("brk;        %8lx %8lx\n", mm.start_brk, mm.brk);
+	mprintf("stack:      %8lx\n", mm.start_stack);
+	mprintf("arg:        %8lx %8lx\n", mm.arg_start, mm.arg_end);
+	mprintf("env:        %8lx %8lx\n", mm.env_start, mm.env_end);
 
 	if (vflag) {
 		prhead_vm_area_struct();
@@ -291,3 +301,19 @@ search_task(addr)
 
 	return 0;	/* not found */
 }
+
+addr_t
+define_task(addr)
+	addr_t addr;
+{
+	struct task_struct tsk;
+	struct mm_struct mm;
+
+	memread(addr, sizeof(tsk), &tsk, "task_struct");
+	if (tsk.mm) {
+		memread((addr_t)tsk.mm, sizeof(mm), &mm, "mm_struct");
+		load_pgd((addr_t)mm.pgd);
+		return (addr_t)mm.pgd;
+	}
+	return 0;
+}
