@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
@@ -55,7 +55,9 @@ struct sizetbl sizetbl[] = {
 	{ "nfs_fh",		sizeof(struct nfs_fh) },
 	{ "nlink_t",		sizeof(nlink_t) },
 	{ "page",		sizeof(struct page) },
+	{ "pgd_t",		sizeof(pgd_t) },
 	{ "pglist_data",	sizeof(struct pglist_data) },
+	{ "pte_t",		sizeof(pte_t) },
 	{ "pv_disk_t",		sizeof(pv_disk_t) },
 	{ "pv_t",		sizeof(pv_t) },
 	{ "request",		sizeof(struct request) },
