@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
@@ -108,9 +108,9 @@ print_kmem_cache(addr, sflag, full)
 		mprintf("slabp_cache   " FPTR "\n", cache.slabp_cache);
 		mprintf("growing      %x\n", cache.growing);
 		mprintf("dflags       %x\n", cache.dflags);
-		p = getsymstr((addr_t)cache.ctor);
+		p = getsymstr_func((addr_t)cache.ctor);
 		mprintf("ctor/dtor    %s", p? p: "NULL");
-		p = getsymstr((addr_t)cache.dtor);
+		p = getsymstr_func((addr_t)cache.dtor);
 		mprintf("  %s\n", p? p: "NULL");
 		mprintf("failures     %lx\n", cache.failures);
 		mprintf("name         \"");
@@ -164,7 +164,7 @@ search_slab(addr)
 	static kmem_cache_t cache;
 	addr_t kmaddr, saddr;
 	slab_t slab;
-	int len, n;
+	int len, n, cnt;
 
 	kmaddr = cache_cache_addr;
 	do {
@@ -172,27 +172,42 @@ search_slab(addr)
 		len = cache.objsize * cache.num;
 
 #if SUBLEVEL >= 9
+		cnt = 0;
 		saddr = (addr_t)cache.slabs_full.next - OFFSET(slab_t, list);
 		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, slabs_full)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
+			if (++cnt > 65536) {
+				mprintf("loop?\n");
+				break;
+			}
 		}
+		cnt = 0;
 		saddr = (addr_t)cache.slabs_partial.next - OFFSET(slab_t, list);
 		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, slabs_partial)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
+			if (++cnt > 65536) {
+				mprintf("loop?\n");
+				break;
+			}
 		}
 #else
+		cnt = 0;
 		saddr = (addr_t)cache.slabs.next - OFFSET(slab_t, list);
 		while (saddr && saddr != kmaddr + OFFSET(kmem_cache_t, slabs)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(slab_t, list);
+			if (++cnt > 65536) {
+				mprintf("loop?\n");
+				break;
+			}
 		}
 #endif
 		kmaddr = (addr_t)cache.next.next - OFFSET(kmem_cache_t, next);
