@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -59,7 +59,7 @@ page()
 			THROW(usage);
 		prhead_page();
 		for (i = optind; i < argcnt; i++) {
-			addr = print_page(mem_map + size * getaddr(args[i]), 0);
+			addr = print_page(mem_map + size * getvalue(args[i]), 0);
 		}
 		return addr;
 	}
@@ -67,7 +67,7 @@ page()
 	if (argcnt > optind) {
 		prhead_page();
 		for (i = optind; i < argcnt; i++) {
-			addr = start = getaddr(args[i]);
+			addr = start = getvalue(args[i]);
 			do {
 				addr = print_page(addr, aflag);
 			} while (aflag && addr && addr != start);
@@ -111,7 +111,7 @@ vm_area_struct()
 		THROW(usage);
 	}
 	while (args[optind]) {
-		addr = print_vm_area_struct(getaddr(args[optind]), full);
+		addr = print_vm_area_struct(getvalue(args[optind]), full);
 		optind++;
 	}
 	return addr;
@@ -145,7 +145,7 @@ zone()
 		return addr;
 	}
 	while (args[optind]) {
-		addr = print_zone(getaddr(args[optind]), 1);
+		addr = print_zone(getvalue(args[optind]), 1);
 		optind++;
 	}
 	return addr;
@@ -170,7 +170,7 @@ pglist_data()
 		addr = print_pglist_data(addr);
 	}
 	while (args[optind]) {
-		addr = print_pglist_data(getaddr(args[optind]));
+		addr = print_pglist_data(getvalue(args[optind]));
 		optind++;
 	}
 	return addr;
