@@ -45,7 +45,7 @@ usb_driver()
 	} else {
 		prhead_usb_driver();
 		while (args[optind]) {
-			addr = print_usb_driver(getaddr(args[optind]), 0, nflag);
+			addr = print_usb_driver(getvalue(args[optind]), 0, nflag);
 			optind++;
 		}
 	}
@@ -77,7 +77,7 @@ usb_bus()
 	} else {
 		prhead_usb_bus();
 		while (args[optind]) {
-			addr = print_usb_bus(getaddr(args[optind]), 0);
+			addr = print_usb_bus(getvalue(args[optind]), 0);
 			optind++;
 		}
 	}
@@ -102,7 +102,7 @@ usb_device()
 	} else {
 		prhead_usb_device();
 		while (args[optind]) {
-			addr = print_usb_device(getaddr(args[optind]), 0);
+			addr = print_usb_device(getvalue(args[optind]), 0);
 			optind++;
 		}
 	}
