@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -33,7 +33,7 @@ request_queue()
 		THROW(usage);
 	}
 	while (args[optind]) {
-		(void) print_request_queue(getaddr(args[optind]), full);
+		(void) print_request_queue(getvalue(args[optind]), full);
 		optind++;
 	}
 	return 0;
@@ -56,7 +56,7 @@ request()
 		THROW(usage);
 	}
 	while (args[optind]) {
-		(void) print_request(getaddr(args[optind]), full);
+		(void) print_request(getvalue(args[optind]), full);
 		optind++;
 	}
 	return 0;
