@@ -69,10 +69,12 @@ prhead_task(sw)
 	case 2:
 		p = "FS";	break;
 	case 3:
-		p = "USER";	break;
+		p = "FILES";	break;
 	case 4:
-		p = "SIGNAL";	break;
+		p = "USER";	break;
 	case 5:
+		p = "SIGNAL";	break;
+	case 6:
 		p = "NAMESPAC";	break;
 	}
 	mprintf(SPTR" S   PID   SID   UID  EUID "SPTR" NAME             FLAGS\n",
@@ -111,10 +113,12 @@ print_task(addr, full, sw)
 	case 2:
 		mprintf(FPTR, ts.fs);	break;
 	case 3:
-		mprintf(FPTR, ts.user);	break;
+		mprintf(FPTR, ts.files);break;
 	case 4:
-		mprintf(FPTR, ts.signal);	break;
+		mprintf(FPTR, ts.user);	break;
 	case 5:
+		mprintf(FPTR, ts.signal);	break;
+	case 6:
 		mprintf(FPTR, ts.namespace);	break;
 	}
 	mprintf(" %-16s", ts.comm);
@@ -211,6 +215,12 @@ print_mm_struct(addr, vflag)
 	mprintf("mm_users:   %x\n", ATOMIC_READ(mm.mm_count));
 	mprintf("map_count:  %x\n", mm.map_count);
 	mprintf("mmlist:     " FPTR " " FPTR "\n", mm.mmlist.next, mm.mmlist.prev);
+	mprintf("code:       %8lx %8lx\n", mm.start_code, mm.end_code);
+	mprintf("data:       %8lx %8lx\n", mm.start_data, mm.end_data);
+	mprintf("brk;        %8lx %8lx\n", mm.start_brk, mm.brk);
+	mprintf("stack:      %8lx\n", mm.start_stack);
+	mprintf("arg:        %8lx %8lx\n", mm.arg_start, mm.arg_end);
+	mprintf("env:        %8lx %8lx\n", mm.env_start, mm.env_end);
 
 	if (vflag) {
 		prhead_vm_area_struct();
@@ -250,3 +260,19 @@ search_task(addr)
 
 	return 0;	/* not found */
 }
+
+addr_t
+define_task(addr)
+	addr_t addr;
+{
+	struct task_struct tsk;
+	struct mm_struct mm;
+
+	memread(addr, sizeof(tsk), &tsk, "task_struct");
+	if (tsk.mm) {
+		memread((addr_t)tsk.mm, sizeof(mm), &mm, "mm_struct");
+		load_pgd((addr_t)mm.pgd);
+		return (addr_t)mm.pgd;
+	}
+	return 0;
+}
