@@ -151,9 +151,9 @@ print_kmem_cache(addr, sflag, full, next)
 		mprintf("colour_next  %x\n", cache.colour_next);
 		mprintf("slabp_cache   " FPTR "\n", cache.slabp_cache);
 		mprintf("dflags       %x\n", cache.dflags);
-		p = getsymstr((addr_t)cache.ctor);
+		p = getsymstr_func((addr_t)cache.ctor);
 		mprintf("ctor/dtor    %s", p? p: "NULL");
-		p = getsymstr((addr_t)cache.dtor);
+		p = getsymstr_func((addr_t)cache.dtor);
 		mprintf("  %s\n", p? p: "NULL");
 		mprintf("name         \"");
 		mprint_str(name, sizeof(name));
@@ -181,12 +181,13 @@ search_slab(addr)
 	kmem_cache_t cache;
 	struct slab slab;
 	char name[64];
-	int len, n;
+	int len, n, cnt;
 
 	memread(cache_chain_addr, sizeof(kmaddr), &kmaddr, "cache_chain");
 	while (kmaddr && kmaddr != cache_chain_addr) {
 		memread(kmaddr - OFFSET(kmem_cache_t, next), sizeof(cache), &cache, "kmem_cache_t");
 		len = cache.objsize * cache.num;
+		cnt = 0;
 
 		saddr = (addr_t)cache.lists.slabs_full.next - OFFSET(struct slab, list);
 		while (saddr && saddr != kmaddr - OFFSET(kmem_cache_t, next) + OFFSET(kmem_cache_t, lists.slabs_full)) {
@@ -194,13 +195,18 @@ search_slab(addr)
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
+			if (++cnt > 65536)
+				break;
 		}
+		cnt = 0;
 		saddr = (addr_t)cache.lists.slabs_partial.next - OFFSET(struct slab, list);
 		while (saddr && saddr != kmaddr - OFFSET(kmem_cache_t, next) + OFFSET(kmem_cache_t, lists.slabs_partial)) {
 			memread(saddr, sizeof(slab), &slab, "slab_t");
 			if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
 				goto found;
 			saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
+			if (++cnt > 65536)
+				break;
 		}
 		kmaddr = (addr_t)cache.next.next;
 	}
