@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #ifndef MPERCPU_H
@@ -10,13 +10,16 @@
 extern addr_t __per_cpu_offset_addr;	/*long*/
 #define	PER_CPU_NAME(var)	var##__per_cpu
 #define	IMPORT_PER_CPU(var)	addr_t var##__per_cpu_addr
-#define	PER_CPU_ADDR(type, var, n)	(var##__per_cpu_addr + sizeof(type) * (n))
+#define	PER_CPU_ADDR(var,cpu)	(var##__per_cpu_addr + __per_cpu_offset[cpu])
+extern addr_t __per_cpu_offset_addr;
+extern unsigned long __per_cpu_offset[];
 
 #else /*CONFIG_SMP*/
 
 #define	PER_CPU_NAME(var)	var##__per_cpu
 #define	IMPORT_PER_CPU(var)	addr_t var##__per_cpu_addr
-#define	PER_CPU_ADDR(type, var, n)	var##__per_cpu_addr
+#define	PER_CPU_ADDR(var,cpu)	var##__per_cpu_addr
+extern unsigned long __per_cpu_offset[];
 
 #endif /*CONFIG_SMP*/
 
