@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -14,7 +14,7 @@ extern addr_t print_neighbour();
 PRIVATE addr_t
 neighbour()
 {
-	addr_t addr;
+	addr_t addr = 0;
 	int c;
 
 	while ((c = getopt(argcnt, args, "")) != EOF) {
@@ -29,7 +29,7 @@ neighbour()
 	} else {
 		prhead_neighbour();
 		while (args[optind]) {
-			addr = print_neighbour(getaddr(args[optind]));
+			addr = print_neighbour(getvalue(args[optind]));
 			optind++;
 		}
 	}
