@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -95,7 +95,7 @@ print_operations(addr, op)
 	memread(addr, sizeof(buf), buf, "operations");
 	mprintf(head_operations, op[0]);
 	for (i = 1; op[i]; i++) {
-		p = getsymstr(buf[i - 1]);
+		p = getsymstr_func(buf[i - 1]);
 		mprintf("%24s:  " FPTR "  %s\n", op[i], buf[i - 1], p? p: "-");
 	}
 }
@@ -145,7 +145,7 @@ operations()
 	}
 
 	for (i = optind; i < argcnt; i++) {
-		addr = getaddr(args[i]);
+		addr = getvalue(args[i]);
 		print_operations(addr, op);
 	}
 	return 0;
