@@ -2,11 +2,13 @@
 
 extern const commandtable_t
 	command_address_space,
+	command_binfmt,
 	command_block_device,
 	command_buffer_head,
 	command_ext2_inode,
 	command_fib_table,
 	command_file,
+	command_file_lock,
 	command_files_stat,
 	command_inode,
 	command_kmem_cache,
@@ -20,6 +22,7 @@ extern const commandtable_t
 	command_slab,
 	command_sock,
 	command_socket,
+	command_swap_info,
 	command_timer_vec,
 	command_usb_bus,
 	command_usb_device,
@@ -30,11 +33,13 @@ extern const commandtable_t
 
 const commandtable_t *commandtable_vers[] = {
 	&command_address_space,
+	&command_binfmt,
 	&command_block_device,
 	&command_buffer_head,
 	&command_ext2_inode,
 	&command_fib_table,
 	&command_file,
+	&command_file_lock,
 	&command_files_stat,
 	&command_inode,
 	&command_kmem_cache,
@@ -48,6 +53,7 @@ const commandtable_t *commandtable_vers[] = {
 	&command_slab,
 	&command_sock,
 	&command_socket,
+	&command_swap_info,
 	&command_timer_vec,
 #ifdef CONFIG_USB
 	&command_usb_bus,
