@@ -1,9 +1,11 @@
 #include "crash.h"
 
-extern struct commandtable command_dis, command_trace;
+extern struct commandtable command_dis, command_trace, command_pte, command_pgd;
 
 const struct commandtable *commandtable_arch[] = {
 	&command_dis,
+	&command_pgd,
+	&command_pte,
 	&command_trace,
 };
 const int ncmdtable_arch = LENGTHOF(commandtable_arch);
