@@ -22,14 +22,14 @@ trace()
 	const struct symtable *sym;
 	unsigned char funchead[34];	/* MAGIC NUMBER 34 :) */
 	int pid;
-	extern const char *getaddrmod();
+	extern const char *getvaluemod();
 
 	if (argcnt < 2 || argcnt > 2) {
 		THROW(usage);
 	}
 
 	eip = esp = stacktop = 0;
-	pid = getinfo_fromtask(getaddr(args[1]), &eip, &esp, &stacktop);
+	pid = getinfo_fromtask(getvalue(args[1]), &eip, &esp, &stacktop);
 	mprintf("PID = %d\n", pid);
 	memread(stacktop, sizeof(stack), stack, "stack area");
 	mprintf(" %8lx  %8lx  ", esp, eip);
@@ -74,7 +74,7 @@ trace()
 			/* mov ebp,esp */
 			if (funchead[1] == 0x89 && funchead[2] == 0xe5) {
 				addr_t tmp = *(addr_t *)&stack[esp - stacktop - sizeof(addr_t)];
-				if (INTHESTACK(tmp)) {
+				if (INTHESTACK(tmp) && esp <= tmp) {
 					/* i wonder this coding no effect now */
 					esp = tmp + sizeof(addr_t);
 					i = sizeof(funchead);
@@ -136,7 +136,8 @@ trace()
 				break;	/* for sys_lstat64 */
 			/* add esp,xx */
 			} else if (c == 0x83 && i < sizeof(funchead) - 2 && funchead[i + 1] == 0xc4) {
-				esp += (signed char)funchead[i + 2];
+				/* unsigned? but it makes loop */
+				esp += funchead[i + 2];
 				i += 3;
 				continue;
 			/* sub esp,xx */
@@ -150,7 +151,7 @@ trace()
 			/* GRP-A */
 			} else if (code1[c].type == GROUPA) {
 				i += code1[c].nbyte;
-				(void)getaddrmod(1, funchead + i - 1, &i);
+				(void)getvaluemod(1, funchead + i - 1, &i);
 				if (c == 0x81)
 					i += 4;
 				else
@@ -166,11 +167,11 @@ trace()
 #endif
 			else if (code1[c].type == MOD0_4 || code1[c].type == MOD1_4 || code1[c].type == GROUPE) {
 				i += code1[c].nbyte;
-				(void)getaddrmod(1, funchead + i - 1, &i);
+				(void)getvaluemod(1, funchead + i - 1, &i);
 				continue;
 			} else if (code1[c].type == MOD0_1 || code1[c].type == MOD1_1 || code1[c].type == GROUPD) {
 				i += code1[c].nbyte;
-				(void)getaddrmod(0, funchead + i - 1, &i);
+				(void)getvaluemod(0, funchead + i - 1, &i);
 				continue;
 			} else if (code1[c].type == OP2B) {
 				i += code2[funchead[i + 1]].nbyte;
@@ -258,15 +259,15 @@ trace()
 				break;
 			} else if (code1[c].type == MOD0_4 || code1[c].type == MOD1_4 || code1[c].type == GROUPE) {
 				i += code1[c].nbyte;
-				(void)getaddrmod(1, funchead + i - 1, &i);
+				(void)getvaluemod(1, funchead + i - 1, &i);
 			} else if (code1[c].type == MOD0_1 || code1[c].type == MOD1_1 || code1[c].type == GROUPD) {
 				i += code1[c].nbyte;
-				(void)getaddrmod(0, funchead + i - 1, &i);
+				(void)getvaluemod(0, funchead + i - 1, &i);
 			} else if (c == 0x0f) {
 				break;
 			} else if (c == 0xc7) {
 				i += code1[c].nbyte;
-				(void)getaddrmod(1, funchead + i - 1, &i);
+				(void)getvaluemod(1, funchead + i - 1, &i);
 				i += 4;
 			/* jxx */
 			} else if (code1[c].type == RELAD1) {
