@@ -289,6 +289,8 @@ mprintf(fmt, va_alist)
 				(void)va_arg(ap, char *);
 				break;
 			}
+			if (save_cnt >= MAXARGS)
+				save_cnt--;
 			break;
 
 		case '\n':
@@ -321,7 +323,9 @@ mprintbit(bit, flag)
 		}
 		bit++;
 	}
-	save_ad[save_cnt++] = flag;
+	save_ad[save_cnt] = flag;
+	if (save_cnt < MAXARGS - 1)
+		save_cnt++;
 
 	if (sigpiped) {
 		sigpiped = 0;
