@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "time.h"
@@ -34,7 +34,7 @@ date_cmd()
 		mprintf("%08lx  %s\n", ti, buf);
 	} else {
 		while (args[optind]) {
-			ti = (time_t)getaddr(args[optind]);
+			ti = (time_t)getvalue(args[optind]);
 			strftime(buf, sizeof(buf), fmt, localtime(&ti));
 			mprintf("%08lx:  %s\n", ti, buf);
 			optind++;
