@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #ifndef DEF_H
@@ -60,11 +60,16 @@ typedef enum prmode {
 
 #ifdef __STDC__
 extern void addsym(const char *name, addr_t value, int type);
-extern addr_t getaddr(const char *str);
-extern int memread(addr_t addr, addr_t size, void *buf, const char *errmsg);
+extern addr_t getvalue(const char *str);
+extern addr_t pa(addr_t);
+extern void memread(addr_t addr, addr_t size, void *buf, const char *errmsg);
+extern void ll_memread(addr_t addr, addr_t size, void *buf, const char *errmsg);
+extern void load_pgd(addr_t addr);
+extern addr_t translate_addr(addr_t addr, addr_t *count, const char *errmsg);
 extern addr_t searchaddr_bysym(const char *name);
 extern const struct symtable *searchsym_byaddr(addr_t addr);
 extern const char *getsymstr(addr_t addr);
+extern const char *getsymstr_func(addr_t addr);
 extern void printxd(const unsigned char *p, addr_t addr, int size, prmode_t);
 extern void mprintf(const char *fmt, ...)
 	__attribute__ ((format (printf, 1, 2)));
