@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <ctype.h>
@@ -9,9 +9,12 @@
 #include <unistd.h>
 #include "crash.h"
 
-PRIVATE addr_t dump();
+PRIVATE addr_t dump(), searchmem();
 const commandtable_t command_dump =
 	{"dump", dump, "[-h|w|d|2|4|8] address [size]", "dump virtual memory\n\t-h | -2  print by half word\n\t-w | -4  print by word\n\t-d | -8  print by double word"};
+const commandtable_t command_search =
+	{"search", searchmem, "address size value", "search {value} from memory between {address} and {address}+{size}"};
+
 
 static char chr2d[256];
 static const char int2h[] = "0123456789abcdef";
@@ -198,12 +201,12 @@ dump()
 #endif /*DEBUG*/
 		THROW(usage);
 	}
-	addr = getaddr(args[optind]);
+	addr = getvalue(args[optind]);
 	if (addr & ((int)mode - 1)) {
 		THROW("invalid address");
 	}
 	if (argcnt - optind >= 2) {
-		size = (int)getaddr(args[optind + 1]);
+		size = (int)getvalue(args[optind + 1]);
 	}
 	if (size & ((int)mode - 1)) {
 		THROW("invalid size");
@@ -211,3 +214,59 @@ dump()
 	printxd(NULL, addr, size, mode);
 	return 0;
 }
+
+PRIVATE void
+dosearchmem(addr, size, val)
+	addr_t addr;
+	addr_t size;
+	addr_t val;
+{
+	addr_t i;
+	int j, cnt;
+	addr_t membuf[65536 / sizeof(val)];
+
+	for (i = 0; i < size; i += sizeof(membuf), addr += sizeof(membuf)) {
+		cnt = sizeof(membuf);
+		if (cnt > size - i)
+			cnt = size - i;
+		memread(addr, cnt, membuf, "memory");
+		cnt /= sizeof(val);
+		for (j = 0; j < cnt; j++) {
+			if (val == membuf[j]) {
+				mprintf("FOUND: " FPTR "\n", addr + j * sizeof(val));
+			}
+		}
+	}
+}
+
+PRIVATE addr_t
+searchmem()
+{
+	int c;
+	addr_t addr, size, val;
+
+	while ((c = getopt(argcnt, args, "")) != EOF) {
+		switch (c) {
+		default:
+			THROW(usage);
+		}
+	}
+
+	if (argcnt - optind != 3)
+		THROW(usage);
+
+	addr = getvalue(args[optind]);
+	if (addr % sizeof(addr)) {
+		THROW("invalid address");
+	}
+
+	size = getvalue(args[optind + 1]);
+	if (size % sizeof(addr)) {
+		THROW("invalid size");
+	}
+
+	val = getvalue(args[optind + 2]);
+
+	dosearchmem(addr, size, val);
+	return 0;
+}
