@@ -34,7 +34,7 @@ module()
 	if (argcnt > optind) {
 		if (!full) prhead_module();
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			if (full) prhead_module();
 			addr = print_module(addr, full);
 		}
