@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <sys/types.h>
@@ -24,8 +24,9 @@ PRIVATE struct symtable *symhash[NHASH];
 
 PRIVATE int mem;
 
-PRIVATE addr_t kmem_low = 0;
-PRIVATE addr_t kmem_high = -1;
+addr_t kmem_low = 0;
+addr_t kmem_high = -1;
+addr_t high_memory;
 
 void
 init_mem()
@@ -45,19 +46,15 @@ init_mem()
 	(void)fcntl(mem, F_SETFD, 1);
 }
 
-int
-memread(addr, size, buf, errmsg)
+/*
+ *	Low Level reading memoey routine
+ */
+void
+ll_memread(addr, size, buf, errmsg)
 	addr_t addr, size;
 	void *buf;
 	const char *errmsg;
 {
-	if (physname) {
-		/* Currently, not work... */
-#ifdef RESTRICT_KERNEL_MEM
-	} else if (addr < kmem_low) {
-		THROWF("Error: address out of range: %lx", addr);
-#endif
-	}
 	if (lseek(mem, (off_t)addr, SEEK_SET) != (off_t)addr) {
 		THROWF("Error: seek to %lx", addr);
 	}
@@ -65,7 +62,33 @@ memread(addr, size, buf, errmsg)
 	if (read(mem, buf, (size_t)size) != (size_t)size) {
 		THROWF2("Error: while reading %s address %lx", errmsg, addr);
 	}
-	return 0;
+}
+
+void
+memread(addr, size, buf, errmsg)
+	addr_t addr, size;
+	void *buf;
+	const char *errmsg;
+{
+	if (physname) {
+		do {
+			addr_t count, paddr;
+			count = size;
+			paddr = translate_addr(addr, &count, errmsg);
+			if (count > size)
+				count = size;
+			ll_memread(paddr, size, buf, errmsg);
+			addr += count;
+			buf  += count;
+			size -= count;
+		} while (size);
+		return;
+#ifdef RESTRICT_KERNEL_MEM
+	} else if (addr < kmem_low) {
+		THROWF("Error: address out of range: %lx", addr);
+#endif
+	}
+	ll_memread(addr, size, buf, errmsg);
 }
 
 /* symbol table hash function */
@@ -128,6 +151,7 @@ init_sym()
 	char type;
 	char buf[256];
 	int i, hash;
+	addr_t swapper_pg_dir;
 
 	if (symname == NULL) {
 		symname = "/boot/System.map";
@@ -151,8 +175,10 @@ init_sym()
 		/* drivers/pci/names.c */
 		if (buf[0] == '_' && buf[1] == '_' && (strncmp(buf + 2, "devices_", 8) == 0 || strncmp(buf + 2, "devicestr_", 10) == 0))
 			continue;
-		if (strchr(buf, '.') != 0)
+		if (buf[0] == '.')
 			continue;
+		if (strcmp(buf, "swapper_pg_dir") == 0)
+			swapper_pg_dir = addr;
 #if LINUXVER == 25
 		/* for 2.5 system_call() */
 		if (strcmp(buf, "syscall_call") == 0)
@@ -163,9 +189,14 @@ init_sym()
 	fclose(fp);
 
 	/* available area (System.map must be sorted by address) */
-	kmem_low = symtable[0].addr;
+	kmem_low = symtable[0].addr & ~0x0ffffffful;
 	kmem_high = symtable[nsym - 1].addr;
 
+	/* for default V-P transfer */
+	if (physname) {
+		load_pgd(swapper_pg_dir);
+	}
+
 	/* get module name list */
 	for (i = 0; i < nsym; i++) {
 		const char *p = symtable[i].name? symtable[i].name:
@@ -176,14 +207,14 @@ init_sym()
 		}
 	}
 
-	/* resize symbol table */
+	/* shrink symbol table */
 	symtable = realloc(symtable, nsym * sizeof(struct symtable));
 	nalloc = nsym;
 
 	/* sort by address (for binary search) */
 	qsort(symtable, nsym, sizeof(struct symtable), sfunc);
 
-	/* make hash table */
+	/* make symbol hash table */
 	for (i = 0; i < NHASH; i++) {
 		symhash[i] = NULL;
 	}
@@ -197,6 +228,10 @@ init_sym()
 		symhash[hash] = &symtable[i];
 	}
 
+	if ((addr = searchaddr_bysym("high_memory")) != 0) {
+		memread(addr, sizeof(high_memory), &high_memory, "high_memory");
+	}
+
 	if (!quiet) {
 		mprintf("%d kernel symbols available\n", nsym);
 	}
@@ -375,6 +410,24 @@ getsymstr(addr)
 	return buf;
 }
 
+const char *
+getsymstr_func(addr)
+	addr_t addr;
+{
+#ifdef CONF_INDIRECT_CALL
+	if (addr && (addr & sizeof(addr)) == 0) {
+		static addr_t cached_addr = 0, cached_val;
+		if (cached_addr != addr) {
+			cached_addr = addr;
+			memread(addr, sizeof(addr), &cached_val, "function");
+		}
+		addr = cached_val;
+	}
+#endif /*CONF_INDIRECT_CALL*/
+
+	return getsymstr(addr);
+}
+
 PRIVATE addr_t
 dsymbol()
 {
@@ -398,7 +451,7 @@ dsymbol()
 		THROW(usage);
 	}
 	for (i = optind; args[i]; i++) {
-		addr = getaddr(args[i]);
+		addr = getvalue(args[i]);
 		if ((p = searchsym_byaddr(addr)) != NULL) {
 			if (addr == p->addr) {
 				mprintf("%s\n", p->name);
