@@ -5,6 +5,9 @@
 #include <unistd.h>
 #include "crash.h"
 #include <linux/sys.h>
+#if LINUXVER>=25
+#include <asm/unistd.h>
+#endif
 
 PRIVATE addr_t sys_call();
 const commandtable_t command_sys_call_table =
