@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "crash.h"
@@ -9,6 +9,7 @@ PRIVATE const commandtable_t command_cmd = {"!cmd", NULL, NULL, NULL};
 extern const commandtable_t
 	command_alias,
 	command_date,
+	command_deftask,
 	command_dentry,
 	command_dmesg,
 	command_dsymbol,
@@ -23,6 +24,7 @@ extern const commandtable_t
 	command_module,
 	command_print,
 	command_quit,
+	command_search,
 	command_semaphore,
 	command_set,
 	command_sizeof,
@@ -36,6 +38,7 @@ const commandtable_t *commandtable_base[] = {
 	&command_cmd,			/* must be at first line */
 	&command_alias,
 	&command_date,
+	&command_deftask,
 	&command_dentry,
 	&command_dmesg,
 	&command_dsymbol,
@@ -50,6 +53,7 @@ const commandtable_t *commandtable_base[] = {
 	&command_module,
 	&command_print,
 	&command_quit,
+	&command_search,
 	&command_semaphore,
 	&command_set,
 	&command_sizeof,
