@@ -28,21 +28,21 @@ print_xlog(addr)
 		{ 0,			NULL }
 	};
 
-	mprintf("addr           " FPTR "\n", addr);
+	mprintf("addr           " FPTR "  (%x)\n", addr, sizeof(log));
 	memread(addr, sizeof(log), &log, "xlog_t");
 
 	mprintf("flushcnt       %x\n", log.l_flushcnt);
 	mprintf("ticket_cnt     %x\n", log.l_ticket_cnt);
 	mprintf("ticket_tcnt    %x\n", log.l_ticket_tcnt);
 	mprintf("covered_state  %x\n", log.l_covered_state);
-	mprintf("freelist       " FPTR "\n", log.l_freelist);
-	mprintf("unmount_free   " FPTR "\n", log.l_unmount_free);
-	mprintf("tail           " FPTR "\n", log.l_tail);
-	mprintf("iclog          " FPTR "\n", log.l_iclog);
+	mprintf("freelist       " FPTR "  (xlog_ticket)\n", log.l_freelist);
+	mprintf("unmount_free   " FPTR "  (xlog_ticket)\n", log.l_unmount_free);
+	mprintf("tail           " FPTR "  (xlog_ticket)\n", log.l_tail);
+	mprintf("iclog          " FPTR "  (xlog_in_core)\n", log.l_iclog);
 	mprintf("tail_lsn       %lx\n", log.l_tail_lsn);
 	mprintf("last_sync_lsn  %lx\n", log.l_last_sync_lsn);
-	mprintf("mp             " FPTR "\n", log.l_mp);
-	mprintf("xbuf           " FPTR "\n", log.l_xbuf);
+	mprintf("mp             " FPTR "  (xfs_mount)\n", log.l_mp);
+	mprintf("xbuf           " FPTR "  (page_buf)\n", log.l_xbuf);
 	mprintf("logBBstart     %lx\n", log.l_logBBstart);
 	mprintf("logsize        %x\n", log.l_logsize);
 	mprintf("logBBsize      %x\n", log.l_logBBsize);
@@ -54,7 +54,7 @@ print_xlog(addr)
 	mprintf("iclog_size     %x\n", log.l_iclog_size);
 	mprintf("iclog_size_log %x\n", log.l_iclog_size_log);
 	mprintf("iclog_bufs     %x\n", log.l_iclog_bufs);
-	mprintf("flags         ");
+	mprintf("flags          %x  ", log.l_flags);
 	mprintbit(lflags, log.l_flags);
 	mprintf("\n");
 
@@ -137,7 +137,7 @@ print_xlog_in_core(addr)
 	mprintf("refcnt    %x\n", xic.ic_refcnt);
 	mprintf("roundoff  %x\n", xic.ic_roundoff);
 	mprintf("bwritecnt %x\n", xic.ic_bwritecnt);
-	mprintf("state     %x ", xic.ic_state);
+	mprintf("state     %x  ", xic.ic_state);
 	mprintbit(state, xic.ic_state);
 	mprintf("\n");
 
