@@ -28,7 +28,7 @@ extern addr_t print_semaphore();
 void
 prhead_pagebuf()
 {
-	mprintf(SPTR" "SPTR" HD       BN   OFFSET LENG "SPTR" ERR CNT OFFS "SPTR" FLAGS\n",
+	mprintf(SPTR" "SPTR" HD       BN    OFFSET LENG "SPTR" ERR CNT OFFS "SPTR" FLAGS\n",
 		"ADDR", "TARGET", "ADDR", "PAGES");
 }
 
@@ -39,13 +39,20 @@ print_pagebuf(addr, fflag)
 {
 	page_buf_t pb;
 
+#ifdef _page_buf_s_has_pb_pin_count
 	memread(addr, sizeof(pb), &pb, "page_buf_t");
+#else
+	page_buf_private_t pbp;
+	memread(addr, sizeof(pbp), &pbp, "page_buf_t");
+	pb = pbp.pb_common;
+#endif
+
 	mprintf(FPTR " ", addr);
 
 	mprintf(FPTR, pb.pb_target);
 	mprintf(" %2x", pb.pb_hold);
 	mprintf(" %8lx", pb.pb_bn);
-	mprintf(" %8lx", pb.pb_file_offset);
+	mprintf(" %9llx", pb.pb_file_offset);
 	mprintf(" %4lx", pb.pb_buffer_length);
 	mprintf(" " FPTR, pb.pb_addr);
 	mprintf(" %3x", pb.pb_error);
@@ -63,6 +70,11 @@ print_pagebuf(addr, fflag)
 		mprintf("  fspriv  " FPTR "\n", pb.pb_fspriv);
 		mprintf("  fspriv2 " FPTR "\n", pb.pb_fspriv2);
 		mprintf("  fspriv3 " FPTR "\n", pb.pb_fspriv3);
+#ifdef _page_buf_s_has_pb_pin_count
+		mprintf("  pin_count  %x\n", ATOMIC_READ(pb.pb_pin_count));
+#else
+		mprintf("  pin_count  %x\n", pbp.pb_pin_count);
+#endif
 		mprintf("  sema:\n");
 		prhead_semaphore();
 #ifdef _page_buf_s_has_pb_sema
