@@ -8,6 +8,8 @@
 #include <xfs.h>
 #include <xfs_log.h>
 #include <xfs_trans.h>
+#include <xfs_buf_item.h>
+#include <xfs_inode_item.h>
 
 void
 prhead_xfs_log_item()
@@ -17,8 +19,9 @@ prhead_xfs_log_item()
 }
 
 addr_t
-print_xfs_log_item(addr)
+print_xfs_log_item(addr, full)
 	addr_t addr;
+	int full;
 {
 	xfs_log_item_t li;
 	static const struct bitname liflags[] = {
@@ -54,6 +57,45 @@ print_xfs_log_item(addr)
 	mprintbit(liflags, li.li_flags);
 	mprintf("\n");
 
+	if (full) {
+		switch (li.li_type) {
+		case XFS_LI_BUF: {
+			xfs_buf_log_item_t bli;
+			static const struct bitname bliflags[] = {
+				{ XFS_BLI_HOLD,		"hold" },
+				{ XFS_BLI_DIRTY,	"dirty" },
+				{ XFS_BLI_STALE,	"stale" },
+				{ XFS_BLI_LOGGED,	"logged" },
+				{ XFS_BLI_INODE_ALLOC_BUF, "inode_alloc_buf" },
+				{ 0,			NULL }
+			};
+			memread(addr, sizeof(bli), &bli, "xfs_buf_log_item");
+			mprintf("  buf: " FPTR "\n", bli.bli_buf);
+			mprintf("  flags:    %x ", bli.bli_flags);
+			mprintbit(bliflags, bli.bli_flags);
+			mprintf("\n");
+			mprintf("  recur:    %x\n", bli.bli_recur);
+			mprintf("  refcount: %x\n", ATOMIC_READ(bli.bli_refcount));
+			break;
+		}
+		case XFS_LI_INODE: {
+			static const struct bitname iliflags[] = {
+				{ XFS_ILI_HOLD,		   "hold" },
+				{ XFS_ILI_IOLOCKED_EXCL,   "iolocked_excl" },
+				{ XFS_ILI_IOLOCKED_SHARED, "iolocked_shared" },
+				{ 0,			NULL }
+			};
+			xfs_inode_log_item_t ili;
+			memread(addr, sizeof(ili), &ili, "xfs_inode_log_item");
+			mprintf("  inode: " FPTR "\n", ili.ili_inode);
+			mprintf("  flags:  %x ", ili.ili_flags);
+			mprintbit(iliflags, ili.ili_flags);
+			mprintf("\n");
+			break;
+		}
+		}
+	}
+
 	return (addr_t)li.li_ail.ail_forw;
 }
 
@@ -110,14 +152,36 @@ print_xfs_trans(addr)
 	addr_t addr;
 {
 	struct xfs_trans trans;
+	int i;
+	static const struct bitname tflags[] = {
+		{ XFS_TRANS_DIRTY,	"dirty" },
+		{ XFS_TRANS_SB_DIRTY,	"sb_dirty" },
+		{ XFS_TRANS_PERM_LOG_RES, "perm_log_res" },
+		{ XFS_TRANS_SYNC,	"sync" },
+		{ XFS_TRANS_DQ_DIRTY,	"dq_dirty" },
+		{ XFS_TRANS_RESERVE,	"reserve" },
+		{ 0,			NULL }
+	};
 
 	memread(addr, sizeof(trans), &trans, "xfs_trans_t");
 	mprintf("addr:         " FPTR "\n", addr);
 
-	mprintf("magic:        %x\n", trans.t_magic);
-	mprintf("logcb:        " FPTR "\n", trans.t_logcb);
-	mprintf("forw:         " FPTR "\n", trans.t_forw);
-	mprintf("back:         " FPTR "\n", trans.t_back);
+	mprintf("magic:        %x  ", trans.t_magic);
+	for (i = 0; i < sizeof(trans.t_magic); i++) {
+		int c = ((unsigned char *)&trans.t_magic)[i];
+		if (isascii(c) && isprint(c))
+			mprintf("%c", c);
+		else
+			mprintf(".");
+	}
+	mprintf("\n");
+
+	mprintf("logcb.next:   " FPTR "\n", trans.t_logcb.cb_next);
+	mprintf("logcb.func:   " FPTR " ( " FPTR " )\n",
+					trans.t_logcb.cb_func,
+					trans.t_logcb.cb_arg);
+	mprintf("forw/back:    " FPTR " " FPTR "\n",
+					trans.t_forw, trans.t_back);
 	mprintf("type:         %x  %s\n", trans.t_type, xfs_transaction_type(trans.t_type));
 	mprintf("log_res:      %x\n", trans.t_log_res);
 	mprintf("log_count:    %x\n", trans.t_log_count);
@@ -125,13 +189,15 @@ print_xfs_trans(addr)
 	mprintf("blk_res_used: %x\n", trans.t_blk_res_used);
 	mprintf("rtx_res:      %x\n", trans.t_rtx_res);
 	mprintf("rtx_res_used: %x\n", trans.t_rtx_res_used);
-	mprintf("ticket:       " FPTR "\n", addr + OFFSET(struct xfs_trans, t_ticket));
-	mprintf("sema:         \n");	/*XXX*/
-	mprintf("lsn:          %lx\n", (long)trans.t_ticket);
-	mprintf("mountp:       " FPTR "\n", trans.t_mountp);
+	mprintf("ticket:       " FPTR "  (xlog_ticket)\n", trans.t_ticket);
+	/* mprintf("sema:         \n");	XXX*/
+	mprintf("lsn:          %llx\n", (__s64)trans.t_lsn);
+	mprintf("mountp:       " FPTR "  (xfs_mount)\n", trans.t_mountp);
 	mprintf("dqinfo:       " FPTR "\n", trans.t_dqinfo);
 	mprintf("callback:     " FPTR "\n", trans.t_callback);
-	mprintf("flags:        %x\n", trans.t_flags);
+	mprintf("flags:        %x  ", trans.t_flags);
+	mprintbit(tflags, trans.t_flags);
+	mprintf("\n");
 	mprintf("icount_delta:        %lx\n", trans.t_icount_delta);
 	mprintf("ifree_delta:         %lx\n", trans.t_ifree_delta);
 	mprintf("fdblocks_delta:      %lx\n", trans.t_fdblocks_delta);
@@ -149,7 +215,36 @@ print_xfs_trans(addr)
 	mprintf("rblocks_delta:       %lx\n", trans.t_rblocks_delta);
 	mprintf("rextents_delta:      %lx\n", trans.t_rextents_delta);
 	mprintf("rextslog_delta:      %lx\n", trans.t_rextslog_delta);
-	mprintf("items_free:   %x\n", trans.t_items_free);
-	mprintf("...\n");
+	mprintf("items_free:          %x\n",  trans.t_items_free);
+	mprintf("items.next:   " FPTR "\n",   trans.t_items.lic_next);
+	mprintf("items.free/unused:   %x %x\n",trans.t_items.lic_free,
+					      trans.t_items.lic_unused);
+	for (i = 0; i < XFS_LIC_NUM_SLOTS; i++) {
+		static const struct bitname lidflags[] = {
+			{ XFS_LID_DIRTY,	"dirty" },
+			{ XFS_LID_PINNED,	"pinned" },
+			{ XFS_LID_SYNC_UNLOCK,	"sync_unlock" },
+			{ 0,			NULL }
+		};
+		if (XFS_LIC_ISFREE(&trans.t_items, i))
+			continue;
+		mprintf("items.descs%2x: " FPTR "%4x %3x ", i,
+			trans.t_items.lic_descs[i].lid_item,
+			trans.t_items.lic_descs[i].lid_size,
+			trans.t_items.lic_descs[i].lid_index);
+		mprintbit(lidflags, trans.t_items.lic_descs[i].lid_flags);
+		mprintf("\n");
+	}
+	mprintf("busy_free:           %x\n", trans.t_busy_free);
+	mprintf("busy.next:    " FPTR "\n",   trans.t_busy.lbc_next);
+	mprintf("busy.free/unused     %x %x\n", trans.t_busy.lbc_free,
+						trans.t_busy.lbc_unused);
+	for (i = 0; i < XFS_LBC_NUM_SLOTS; i++) {
+		if (XFS_LBC_ISFREE(&trans.t_busy, i))
+			continue;
+		mprintf("items.busy %2x: %3x %3x\n", i,
+			trans.t_busy.lbc_busy[i].lbc_ag,
+			trans.t_busy.lbc_busy[i].lbc_idx);
+	}
 	return 0;
 }
