@@ -36,7 +36,7 @@ xfs_mount()
 
 	if (argcnt > optind) {
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			addr = print_xfs_mount(addr, iflag);
 		}
 	} else {
