@@ -35,7 +35,7 @@ pagebuf()
 	if (argcnt > optind) {
 		prhead_pagebuf();
 		for (i = optind; i < argcnt; i++) {
-			start = addr = getaddr(args[i]);
+			start = addr = getvalue(args[i]);
 			do {
 				addr = print_pagebuf(addr, fflag);
 			} while (aflag && addr && start != addr);
