@@ -2,6 +2,7 @@
 
 extern const commandtable_t
 	command_pagebuf,
+	command_xfs_bmbt_rec,
 	command_xfs_inode,
 	command_xfs_log_item,
 	command_xfs_mount,
@@ -13,6 +14,7 @@ extern const commandtable_t
 
 const commandtable_t *commandtable_xfs[] = {
 	&command_pagebuf,
+	&command_xfs_bmbt_rec,
 	&command_xfs_inode,
 	&command_xfs_log_item,
 	&command_xfs_mount,
