@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -22,12 +22,16 @@ xfs_log_item()
 	int i, c;
 	addr_t addr = 0, saddr;
 	int aflag = 0;
+	int full = 0;
 
-	while ((c = getopt(argcnt, args, "a")) != EOF) {
+	while ((c = getopt(argcnt, args, "af")) != EOF) {
 		switch (c) {
 		case 'a':
 			aflag = 1;
 			break;
+		case 'f':
+			full = 1;
+			break;
 		default:
 			THROW(usage);
 		}
@@ -36,9 +40,9 @@ xfs_log_item()
 	if (argcnt > optind) {
 		prhead_xfs_log_item();
 		for (i = optind; i < argcnt; i++) {
-			addr = saddr = getaddr(args[i]);
+			addr = saddr = getvalue(args[i]);
 			do {
-				addr = print_xfs_log_item(addr);
+				addr = print_xfs_log_item(addr, full);
 			} while (aflag && addr && addr != saddr);
 		}
 	} else {
@@ -62,7 +66,7 @@ xfs_trans()
 
 	if (argcnt > optind) {
 		for (i = optind; i < argcnt; i++) {
-			addr = print_xfs_trans(getaddr(args[i]));
+			addr = print_xfs_trans(getvalue(args[i]));
 		}
 	} else {
 		THROW(usage);
