@@ -51,7 +51,7 @@ xfs_vfs()
 
 	if (argcnt > optind) {
 		for (i = 1; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			addr = print_xfs_vfs(addr, full);
 		}
 	} else {
